using System;
using System.Collections;
using System.Threading;

namespace Server
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	public class Timer
	{
		private static int m_BreakCount;
		private int m_Count;
		private TimeSpan m_Delay;
		private int m_Index;
		private TimeSpan m_Interval;
		private ArrayList m_List;
		private DateTime m_Next;
		private TimerPriority m_Priority;
		private static Hashtable m_Profiles;
		private static Queue m_Queue;
		private static int m_QueueCountAtSlice;
		private bool m_Queued;
		private bool m_Running;

		public class TimerThread
		{
			private static Queue m_ChangeQueue = Queue.Synchronized(new Queue());
			private static DateTime[] m_NextPriorities = new DateTime[8];
			private static TimeSpan[] m_PriorityDelays = {
															 TimeSpan.Zero,
															 TimeSpan.FromMilliseconds(10),
															 TimeSpan.FromMilliseconds(25),
															 TimeSpan.FromMilliseconds(50),
															 TimeSpan.FromMilliseconds(250),
															 TimeSpan.FromSeconds(1),
															 TimeSpan.FromSeconds(5),
															 TimeSpan.FromMinutes(1)
														 };
			private static ArrayList[] m_Timers = {
													  new ArrayList(),
													  new ArrayList(),
													  new ArrayList(),
													  new ArrayList(),
													  new ArrayList(),
													  new ArrayList(),
													  new ArrayList(),
													  new ArrayList()
												  };

			public static void AddTimer(Timer t)
			{
				TimerThread.Change(t, t.Priority, 1);
			}

			public static void Change(Timer t, int newIndex, bool isAdd)
			{
				TimerThread.m_ChangeQueue.Enqueue(TimerChangeEntry.GetInstance(t,newIndex,isAdd));
			}

			public static void DumpInfo(TextWriter tw)
			{
					int num1;
				Hashtable hashtable1;
				int num2;
				Timer timer1;
				string text1;
				ArrayList list1;
				DictionaryEntry entry1;
				string text2;
				ArrayList list2;
				IDictionaryEnumerator enumerator1;
				IDisposable disposable1;
				for (num1 = 0; (num1 < 8); num1 = (num1 + 1))
				{
					tw.WriteLine("Priority: {0}", num1);
					tw.WriteLine();
					hashtable1 = new Hashtable();
					for (num2 = 0; (num2 < TimerThread.m_Timers[num1].Count); num2 = (num2 + 1))
					{
						timer1 = ((Timer) TimerThread.m_Timers[num1][num2]);
						text1 = timer1.ToString();
						list1 = ((ArrayList) hashtable1[text1]);
						if (list1 == null)
						{
							list1 = new ArrayList();
							hashtable1[text1] = new ArrayList();
 
						}
						list1.Add(timer1);
 
					}
					enumerator1 = hashtable1.GetEnumerator();
					try
					{
						while (enumerator1.MoveNext())
						{
							entry1 = ((DictionaryEntry) enumerator1.Current);
							text2 = ((string) entry1.Key);
							list2 = ((ArrayList) entry1.Value);
							tw.WriteLine("Type: {0}; Count: {1}; Percent: {2}%", text2, list2.Count, ((int) (100 * (((double) list2.Count) / ((double) TimerThread.m_Timers[num1].Count)))));
 
						}
 
					}
					finally
					{
						disposable1 = (enumerator1 as IDisposable);
						if (disposable1 != null)
						{
							disposable1.Dispose();
 
						}
 
					}
					tw.WriteLine();
					tw.WriteLine();
 
				}
 
			}

			public static void PriorityChange(Timer t, int newPrio)
			{
				TimerThread.Change(t, newPrio, 0);
			}

			private static void ProcessChangeQueue()
			{
					TimerChangeEntry entry1;
				Timer timer1;
				int num1;
				while ((TimerThread.m_ChangeQueue.Count > 0))
				{
					entry1 = ((TimerChangeEntry) TimerThread.m_ChangeQueue.Dequeue());
					timer1 = entry1.m_Timer;
					num1 = entry1.m_NewIndex;
					if (timer1.m_List != null)
					{
						timer1.m_List.Remove(timer1);
 
					}
					if (entry1.m_IsAdd)
					{
						timer1.m_Next = DateTime.op_Addition(DateTime.Now, timer1.m_Delay);
						timer1.m_Index = 0;
 
					}
					if (num1 >= 0)
					{
						timer1.m_List = TimerThread.m_Timers[num1];
						timer1.m_List.Add(timer1);
 
					}
					else
					{
							timer1.m_List = null;
 
					}
 
				}
 
			} 

			public static void RemoveTimer(Timer t)
			{
				TimerThread.Change(t, -1, 0);
			}

			public void TimerMain()
			{
				while (!Core.Closing)
				{
					Thread.Sleep(10);
					TimerThread.ProcessChangeQueue();
					for (int num1=0; num1<TimerThread.m_Timers.Length; num1++)
					{
						DateTime time1 = DateTime.Now;
						if (DateTime.op_LessThan(time1, TimerThread.m_NextPriorities[num1]))
						{
							continue;
						}
						TimerThread.m_NextPriorities[num1] = DateTime.op_Addition(time1, TimerThread.m_PriorityDelays[num1]);
						for (int num2=0; num2<TimerThread.m_Timers[num1].Count; num2++)
						{
							Timer timer1 = ((Timer)TimerThread.m_Timers[num1][num2]);
							if (!timer1.m_Queued && DateTime.op_GreaterThan(time1, timer1.m_Next))
							{
								timer1.m_Queued = true;
								Queue queue1 = Timer.m_Queue;
								lock (Timer.m_Queue)
								{
									Timer.m_Queue.Enqueue(timer1);
								}
								if (timer1.m_Count != 0)
								{
									int num3 = (timer1.m_Index+1);
									timer1.m_Index++;
									if (num3 >= timer1.m_Count)
									{
										timer1.Stop();
										continue;
									}
								}
								timer1.m_Next = DateTime.op_Addition(time1, timer1.m_Interval);
							}
						}
					}
				}
			}
		}

	}
}
