using System;

namespace Server
{
	public delegate void AccountLoginEventHandler(AccountLoginEventArgs e);
	public class AccountLoginEventArgs : EventArgs
	{
		public AccountLoginEventArgs(NetState state, string un, string pw)
		{
			this.m_State = state;
			this.m_Username = un;
			this.m_Password = pw;
		}

		public bool Accepted {
			get
			{
				return this.m_Accepted;
			}
			set
			{
				this.m_Accepted = value;
			}
		}

		public string Password {
			get
			{
				return this.m_Password;
			}
		}

		public ALRReason RejectReason {
			get
			{
				return this.m_RejectReason;
			}
			set
			{
				this.m_RejectReason = value;
			}
		}

		public NetState State {
			get
			{
				return this.m_State;
			}
		}

		public string Username {
			get
			{
				return this.m_Username;
			}
		}

		private bool m_Accepted;
		private string m_Password;
		private ALRReason m_RejectReason;
		private NetState m_State;
		private string m_Username;
	}
 

	public delegate void AggressiveActionEventHandler(AggressiveActionEventArgs e);
	public class AggressiveActionEventArgs : EventArgs
	{
		public static AggressiveActionEventArgs Create(Mobile aggressed, Mobile aggressor, bool criminal)
		{
			AggressiveActionEventArgs args1;
			if (AggressiveActionEventArgs.m_Pool.Count > 0)
			{
				args1 = ((AggressiveActionEventArgs) AggressiveActionEventArgs.m_Pool.Dequeue());
				args1.m_Aggressed = aggressed;
				args1.m_Aggressor = aggressor;
				args1.m_Criminal = criminal;
			}
			else
			{
				args1 = new AggressiveActionEventArgs(aggressed, aggressor, criminal);
			}
			return args1;
		}

		public void Free()
		{
			AggressiveActionEventArgs.m_Pool.Enqueue(this);
		}

		private AggressiveActionEventArgs(Mobile aggressed, Mobile aggressor, bool criminal)
		{
			this.m_Aggressed = aggressed;
			this.m_Aggressor = aggressor;
			this.m_Criminal = criminal;
		}

		public Mobile Aggressed {
			get
			{
				return this.m_Aggressed;
			}
		}

		public Mobile Aggressor {
			get
			{
				return this.m_Aggressor;
			}
		}

		public bool Criminal {
			get
			{
				return this.m_Criminal;
			}
		}

		private static Queue m_Pool = new Queue();

		private Mobile m_Aggressed;
		private Mobile m_Aggressor;
		private bool m_Criminal;
 	}
 
	public delegate bool AllowBeneficialHandler(Mobile from, Mobile target);
 
	public delegate bool AllowHarmfulHandler(Mobile from, Mobile target);
 
	public delegate void AnimateRequestEventHandler(AnimateRequestEventArgs e);
	public class AnimateRequestEventArgs : EventArgs
	{
		public AnimateRequestEventArgs(Mobile m, string action)
		{
			this.m_Mobile = m;
			this.m_Action = action;
		}

		public string Action {
			get
			{
				return this.m_Action;
			}
		}

		public Mobile Mobile {
			get
			{
				return this.m_Mobile;
			}
		}

		private string m_Action;
		private Mobile m_Mobile;
	}

	public delegate void CastSpellRequestEventHandler(CastSpellRequestEventArgs e);
	public class CastSpellRequestEventArgs : EventArgs
	{
		public CastSpellRequestEventArgs(Mobile m, int spellID, Item book)
		{
			this.m_Mobile = m;
			this.m_SpellID = spellID;
			this.m_Spellbook = book;
		}

		public Mobile Mobile {
			get
			{
				return this.m_Mobile;
			}
		}

		public Item Spellbook {
			get
			{
				return this.m_Spellbook;
			}
		}

		public int SpellID {
			get
			{
				return this.m_SpellID;
			}
		}

		private Mobile m_Mobile;
		private Item m_Spellbook;
		private int m_SpellID;
 	}

	public delegate void ChangeProfileRequestEventHandler(ChangeProfileRequestEventArgs e);
	public class ChangeProfileRequestEventArgs : EventArgs
	{
		public ChangeProfileRequestEventArgs(Mobile beholder, Mobile beheld, string text)
		{
			this.m_Beholder = beholder;
			this.m_Beheld = beheld;
			this.m_Text = text;
		}

		public Mobile Beheld {
			get
			{
				return this.m_Beheld;
			}
		}

		public Mobile Beholder {
			get
			{
				return this.m_Beholder;
			}
		}

		public string Text {
			get
			{
				return this.m_Text;
			}
		}

		private Mobile m_Beheld;
		private Mobile m_Beholder;
		private string m_Text;
 	}
 

	public delegate void CharacterCreatedEventHandler(CharacterCreatedEventArgs e);
	public class CharacterCreatedEventArgs : EventArgs
	{
		public CharacterCreatedEventArgs(NetState state, IAccount a, string name, bool female, int hue, int str, int dex, int intel, CityInfo city, SkillNameValue[] skills, int shirtHue, int pantsHue, int hairID, int hairHue, int beardID, int beardHue, int profession)
		{
			this.m_State = state;
			this.m_Account = a;
			this.m_Name = name;
			this.m_Female = female;
			this.m_Hue = hue;
			this.m_Str = str;
			this.m_Dex = dex;
			this.m_Int = intel;
			this.m_City = city;
			this.m_Skills = skills;
			this.m_ShirtHue = shirtHue;
			this.m_PantsHue = pantsHue;
			this.m_HairID = hairID;
			this.m_HairHue = hairHue;
			this.m_BeardID = beardID;
			this.m_BeardHue = beardHue;
			this.m_Profession = profession;
		}

		public IAccount Account { get { return this.m_Account; } }
		public int BeardHue { get { return this.m_BeardHue; } }
		public int BeardID { get { return this.m_BeardID; } }
		public CityInfo City { get { return this.m_City; } }
		public int Dex { get { return this.m_Dex; } }
		public bool Female { get { return this.m_Female; } }
		public int HairHue { get { return this.m_HairHue; } }
		public int HairID { get { return this.m_HairID; } }
		public int Hue { get { return this.m_Hue; } }
		public int Int { get { return this.m_Int; } }
		public Mobile Mobile 
		{
			get { return this.m_Mobile; }
			set { this.m_Mobile = value; }
		}
		public string Name { get { return this.m_Name; } }
		public int PantsHue { get { return this.m_PantsHue; } }
		public int Profession { get { return this.m_Profession; } }
		public int ShirtHue { get { return this.m_ShirtHue; } }
		public SkillNameValue[] Skills { get { return this.m_Skills; } }
		public NetState State { get { return this.m_State; } }
		public int Str { get { return this.m_Str; } }

		private IAccount m_Account;
		private int m_BeardHue;
		private int m_BeardID;
		private CityInfo m_City;
		private int m_Dex;
		private bool m_Female;
		private int m_HairHue;
		private int m_HairID;
		private int m_Hue;
		private int m_Int;
		private Mobile m_Mobile;
		private string m_Name;
		private int m_PantsHue;
		private int m_Profession;
		private int m_ShirtHue;
		private SkillNameValue[] m_Skills;
		private NetState m_State;
		private int m_Str;
	}

	public delegate void ChatRequestEventHandler(ChatRequestEventArgs e);
	public class ChatRequestEventArgs : EventArgs
	{
		public ChatRequestEventArgs(Mobile mobile)
		{
			this.m_Mobile = mobile;
		}

		public Mobile Mobile {
			get
			{
				return this.m_Mobile;
			}
		}

		private Mobile m_Mobile;
	}
 
	public delegate void CommandEventHandler(CommandEventArgs e);
	public class CommandEventArgs : EventArgs
	{
		public CommandEventArgs(Mobile mobile, string command, string argString, string[] arguments)
		{
			this.m_Mobile = mobile;
			this.m_Command = command;
			this.m_ArgString = argString;
			this.m_Arguments = arguments;
		}

		public bool GetBoolean(int index)
		{
				if ((index < 0) || (index >= this.m_Arguments.Length))
		  {
			  return false; 
		  }
			return Utility.ToBoolean(this.m_Arguments[index]); 
		} 

		public double GetDouble(int index)
		{
				if ((index < 0) || (index >= this.m_Arguments.Length))
		  {
			  return 0; 
		  }
			return Utility.ToDouble(this.m_Arguments[index]); 
		} 

		public int GetInt32(int index)
		{
				if ((index < 0) || (index >= this.m_Arguments.Length))
		  {
			  return 0; 
		  }
			return Utility.ToInt32(this.m_Arguments[index]); 
		} 

		public string GetString(int index)
		{
				if ((index < 0) || (index >= this.m_Arguments.Length))
		  {
			  return ""; 
		  }
			return this.m_Arguments[index]; 
		} 

		public TimeSpan GetTimeSpan(int index)
		{
				if ((index < 0) || (index >= this.m_Arguments.Length))
		  {
			  return TimeSpan.Zero; 
		  }
			return Utility.ToTimeSpan(this.m_Arguments[index]); 
		} 

		public string ArgString { get { return this.m_ArgString; } }
		public string[] Arguments { get { return this.m_Arguments; } }
		public string Command { get { return this.m_Command; } }
		public int Length { get { return this.m_Arguments.Length; } }
		public Mobile Mobile { get { return this.m_Mobile; } }

		private string m_ArgString;
		private string[] m_Arguments;
		private string m_Command;
		private Mobile m_Mobile;
	}
 
	public delegate void ConnectedEventHandler(ConnectedEventArgs e);
	public class ConnectedEventArgs : EventArgs
	{
		public ConnectedEventArgs(Mobile m)
		{
			this.m_Mobile = m;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }

		private Mobile m_Mobile;
	}

	public delegate void CrashedEventHandler(CrashedEventArgs e);
	public class CrashedEventArgs : EventArgs
	{
		public CrashedEventArgs(Exception e)
		{
			this.m_Exception = e;
		}

		public bool Close {
			get { return this.m_Close; }
			set { this.m_Close = value; }
		}

		public Exception Exception { get { return this.m_Exception; } }

		private bool m_Close;
		private Exception m_Exception;
	}

	public delegate Container CreateCorpseHandler(Mobile from, ArrayList initialContent, ArrayList equipedItems);
 
	public delegate BaseGuild CreateGuildHandler(CreateGuildEventArgs e);
	public class CreateGuildEventArgs : EventArgs
	{
		public CreateGuildEventArgs(int id)
		{
			this.m_Id = id;
		}

		public int Id {
			get { return this.m_Id; }
			set { this.m_Id = value; }
		}

		private int m_Id;
	}

	public delegate void DeleteRequestEventHandler(DeleteRequestEventArgs e);
	public class DeleteRequestEventArgs : EventArgs
	{
		public DeleteRequestEventArgs(NetState state, int index)
		{
			this.m_State = state;
			this.m_Index = index;
		}

		public int Index { get { return this.m_Index; } }
		public NetState State { get { return this.m_State; } }

		private int m_Index;
		private NetState m_State;
	}

	public delegate void DisarmRequestEventHandler(DisarmRequestEventArgs e);
	public class DisarmRequestEventArgs : EventArgs
	{
		public DisarmRequestEventArgs(Mobile m)
		{
			this.m_Mobile = m;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }

		private Mobile m_Mobile;
	}

	public delegate void DisconnectedEventHandler(DisconnectedEventArgs e);
	public class DisconnectedEventArgs : EventArgs
	{
		public DisconnectedEventArgs(Mobile m)
		{
			this.m_Mobile = m;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }

		private Mobile m_Mobile;
	}

	public delegate void FastWalkEventHandler(FastWalkEventArgs e);
	public class FastWalkEventArgs
	{
		public FastWalkEventArgs(NetState state)
		{
			this.m_State = state;
			this.m_Blocked = false;
		}

		public bool Blocked {
			get { return this.m_Blocked; }
			set { this.m_Blocked = value; }
		}

		public NetState NetState { get { return this.m_State; } }

		private bool m_Blocked;
		private NetState m_State;
	}

	public delegate void GameLoginEventHandler(GameLoginEventArgs e);
	public class GameLoginEventArgs : EventArgs
	{
		public GameLoginEventArgs(NetState state, string un, string pw)
		{
			this.m_State = state;
			this.m_Username = un;
			this.m_Password = pw;
		}

		public bool Accepted { 
			get { return this.m_Accepted; }
			set { this.m_Accepted = value; }
		}

		public CityInfo[] CityInfo { 
			get { return this.m_CityInfo; }
			set { this.m_CityInfo = value; }
		}

		public string Password { get { return this.m_Password; } }
		public NetState State { get { return this.m_State; } }
		public string Username { get { return this.m_Username; } }

		private bool m_Accepted;
		private CityInfo[] m_CityInfo;
		private string m_Password;
		private NetState m_State;
		private string m_Username;
	}

	public delegate void HelpRequestEventHandler(HelpRequestEventArgs e);
	public class HelpRequestEventArgs : EventArgs
	{
		public HelpRequestEventArgs(Mobile m)
		{
			this.m_Mobile = m;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }

		private Mobile m_Mobile;
	}

	public delegate void HungerChangedEventHandler(HungerChangedEventArgs e);
	public class HungerChangedEventArgs : EventArgs
	{
		public HungerChangedEventArgs(Mobile mobile, int oldValue)
		{
			this.m_Mobile = mobile;
			this.m_OldValue = oldValue;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }
		public int OldValue { get { return this.m_OldValue; } }

		private Mobile m_Mobile;
		private int m_OldValue;
	}

	public delegate void LoginEventHandler(LoginEventArgs e);
	public class LoginEventArgs : EventArgs
	{
		public LoginEventArgs(Mobile mobile)
		{
			this.m_Mobile = mobile;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }

		private Mobile m_Mobile;
	}

	public delegate void LogoutEventHandler(LogoutEventArgs e);
	public class LogoutEventArgs : EventArgs
	{
		public LogoutEventArgs(Mobile m)
		{
			this.m_Mobile = m;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }

		private Mobile m_Mobile;
	}

	public delegate void MovementEventHandler(MovementEventArgs e);
	public class MovementEventArgs : EventArgs
	{
		public MovementEventArgs(Mobile mobile, Direction dir)
		{
			this.m_Mobile = mobile;
			this.m_Direction = dir;
		}

		public static MovementEventArgs Create(Mobile mobile, Direction dir)
		{
			MovementEventArgs args1;
			if (MovementEventArgs.m_Pool.Count > 0)
			{
				args1 = ((MovementEventArgs) MovementEventArgs.m_Pool.Dequeue());
				args1.m_Mobile = mobile;
				args1.m_Direction = dir;
				args1.m_Blocked = false;
			}
			else
			{
				args1 = new MovementEventArgs(mobile, dir);
			}
			return args1; 
		}

		public void Free()
		{
			MovementEventArgs.m_Pool.Enqueue(this);
		}

		public bool Blocked { 
			get { return this.m_Blocked; }
			set { this.m_Blocked = value; }
		}

		public Direction Direction { get { return this.m_Direction; } }
		public Mobile Mobile { get { return this.m_Mobile; } }

		private bool m_Blocked;
		private Direction m_Direction;
		private Mobile m_Mobile;
		private static Queue m_Pool = new Queue();
	}

	public delegate int NotorietyHandler(Mobile source, Mobile target);
 
	public delegate void OpenDoorMacroEventHandler(OpenDoorMacroEventArgs e);
	public class OpenDoorMacroEventArgs : EventArgs
	{
		public OpenDoorMacroEventArgs(Mobile mobile)
		{
			this.m_Mobile = mobile;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }

		private Mobile m_Mobile;
	}

	public delegate void OpenSpellbookRequestEventHandler(OpenSpellbookRequestEventArgs e);
	public class OpenSpellbookRequestEventArgs : EventArgs
	{
		public OpenSpellbookRequestEventArgs(Mobile m, int type)
		{
			this.m_Mobile = m;
			this.m_Type = type;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }
		public int Type { get { return this.m_Type; } }

		private Mobile m_Mobile;
		private int m_Type;
 
	}

	public delegate void PaperdollRequestEventHandler(PaperdollRequestEventArgs e);
	public class PaperdollRequestEventArgs : EventArgs
	{
		public PaperdollRequestEventArgs(Mobile beholder, Mobile beheld)
		{
			this.m_Beholder = beholder;
			this.m_Beheld = beheld;
		}

		public Mobile Beheld { get { return this.m_Beheld; } }
		public Mobile Beholder { get { return this.m_Beholder; } }

		private Mobile m_Beheld;
		private Mobile m_Beholder;
	}

	public delegate void PlayerDeathEventHandler(PlayerDeathEventArgs e);
	public class PlayerDeathEventArgs : EventArgs
	{
		public PlayerDeathEventArgs(Mobile mobile)
		{
			this.m_Mobile = mobile;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }

		private Mobile m_Mobile;
	}

	public delegate void ProfileRequestEventHandler(ProfileRequestEventArgs e);
	public class ProfileRequestEventArgs : EventArgs
	{
		public ProfileRequestEventArgs(Mobile beholder, Mobile beheld)
		{
			this.m_Beholder = beholder;
			this.m_Beheld = beheld;
		}

		public Mobile Beheld { get { return this.m_Beheld; } }
		public Mobile Beholder { get { return this.m_Beholder; } }

		private Mobile m_Beheld;
		private Mobile m_Beholder;
	}

	public delegate TimeSpan RegenRateHandler(Mobile from);
 
	public delegate void RenameRequestEventHandler(RenameRequestEventArgs e);
	public class RenameRequestEventArgs : EventArgs
	{
		public RenameRequestEventArgs(Mobile from, Mobile target, string name)
		{
			this.m_From = from;
			this.m_Target = target;
			this.m_Name = name;
		}

		public Mobile From { get { return this.m_From; } }
		public string Name { get { return this.m_Name; } }
		public Mobile Target { get { return this.m_Target; } }

		private Mobile m_From;
		private string m_Name;
		private Mobile m_Target;
	}

	public delegate void ServerListEventHandler(ServerListEventArgs e);
	public class ServerListEventArgs : EventArgs
	{
		public ServerListEventArgs(NetState state, IAccount account)
		{
			this.m_State = state;
			this.m_Account = account;
			this.m_Servers = new ArrayList();
		}

		public void AddServer(string name, int fullPercent, TimeZone tz, IPEndPoint address)
		{
			this.m_Servers.Add(new ServerInfo(name, fullPercent, tz, address));
		}

		public void AddServer(string name, IPEndPoint address)
		{
				this.AddServer(name, 0, TimeZone.CurrentTimeZone, address);
		} 

		public IAccount Account { get { return this.m_Account; } }

		public bool Rejected { 
			get { return this.m_Rejected; }
			set { this.m_Rejected = value; }
		}

		public ArrayList Servers { get { return this.m_Servers; } }
		public NetState State { get { return this.m_State; } }

		private IAccount m_Account;
		private bool m_Rejected;
		private ArrayList m_Servers;
		private NetState m_State;
	}

	public delegate void ServerStartedEventHandler();
 
	public delegate void SetAbilityEventHandler(SetAbilityEventArgs e);
	public class SetAbilityEventArgs : EventArgs
	{
		public SetAbilityEventArgs(Mobile mobile, int index)
		{
			this.m_Mobile = mobile;
			this.m_Index = index;
		}

		public int Index { get { return this.m_Index; } }
		public Mobile Mobile { get { return this.m_Mobile; } }

		private int m_Index;
		private Mobile m_Mobile;
	}

	public delegate void ShutdownEventHandler(ShutdownEventArgs e);
	public class ShutdownEventArgs : EventArgs
	{
		public ShutdownEventArgs()
		{
		}
	}

	public delegate bool SkillCheckDirectLocationHandler(Mobile from, SkillName skill, double chance);
 
	public delegate bool SkillCheckDirectTargetHandler(Mobile from, SkillName skill, object target, double chance);
 
	public delegate bool SkillCheckLocationHandler(Mobile from, SkillName skill, double minSkill, double maxSkill);
 
	public delegate bool SkillCheckTargetHandler(Mobile from, SkillName skill, object target, double minSkill, double maxSkill);
 
	public delegate TimeSpan SkillUseCallback(Mobile user);
 
	public delegate void Slice();
 
	public delegate void SpeechEventHandler(SpeechEventArgs e);
	public class SpeechEventArgs : EventArgs
	{
		public SpeechEventArgs(Mobile mobile, string speech, MessageType type, int hue, int[] keywords)
		{
			this.m_Mobile = mobile;
			this.m_Speech = speech;
			this.m_Type = type;
			this.m_Hue = hue;
			this.m_Keywords = keywords;
		}

		public bool HasKeyword(int keyword)
		{
			int num1;
			for (num1 = 0; (num1 < this.m_Keywords.Length); num1 = (num1 + 1))
			{
				if (this.m_Keywords[num1] == keyword)
				{
					return true; 
				}
 			}
			return false; 
		} 

		public bool Blocked { 
			get { return this.m_Blocked; }
			set { this.m_Blocked = value; }
		}

		public bool Handled { 
			get { return this.m_Handled; }
			set { this.m_Handled = value; }
		}

		public int Hue { get { return this.m_Hue; } }
		public int[] Keywords { get { return this.m_Keywords; } }
		public Mobile Mobile { get { return this.m_Mobile; } }

		public string Speech { 
			get { return this.m_Speech; }
			set { this.m_Speech = value; }
		}

		public MessageType Type { get { return this.m_Type; } }

		private bool m_Blocked;
		private bool m_Handled;
		private int m_Hue;
		private int[] m_Keywords;
		private Mobile m_Mobile;
		private string m_Speech;
		private MessageType m_Type;
	}

	public delegate void StunRequestEventHandler(StunRequestEventArgs e);
	public class StunRequestEventArgs : EventArgs
	{
		public StunRequestEventArgs(Mobile m)
		{
			this.m_Mobile = m;
		}

		public Mobile Mobile { get { return this.m_Mobile; } }
		private Mobile m_Mobile;
 	}

	public delegate void TargetCallback(Mobile from, object targeted);
 
	public delegate void TargetStateCallback(Mobile from, object targeted, object state);
 
	public delegate void TimerCallback();
 
	public delegate void TimerStateCallback(object state);
 
	public delegate void VirtueGumpRequestEventHandler(VirtueGumpRequestEventArgs e);
	public class VirtueGumpRequestEventArgs : EventArgs
	{
		public VirtueGumpRequestEventArgs(Mobile beholder, Mobile beheld)
		{
			this.m_Beholder = beholder;
			this.m_Beheld = beheld;
		}

		public Mobile Beheld { get { return this.m_Beheld; } }
		public Mobile Beholder { get { return this.m_Beholder; } }

		private Mobile m_Beheld;
		private Mobile m_Beholder;
	}

	public delegate void VirtueItemRequestEventHandler(VirtueItemRequestEventArgs e);
	public class VirtueItemRequestEventArgs : EventArgs
	{
		public VirtueItemRequestEventArgs(Mobile beholder, Mobile beheld, int gumpID)
		{
			this.m_Beholder = beholder;
			this.m_Beheld = beheld;
			this.m_GumpID = gumpID;
		}

		public Mobile Beheld { get { return this.m_Beheld; } }
		public Mobile Beholder { get { return this.m_Beholder; } }
		public int GumpID { get { return this.m_GumpID; } }

		private Mobile m_Beheld;
		private Mobile m_Beholder;
		private int m_GumpID;
	}

	public delegate void WorldLoadEventHandler();
 
	public delegate void WorldSaveEventHandler(WorldSaveEventArgs e);
	public class WorldSaveEventArgs : EventArgs
	{
		public WorldSaveEventArgs(bool msg)
		{
			this.m_Msg = msg;
		}

		public bool Message { get { return this.m_Msg; } }

		private bool m_Msg;
	}
}